use crate::{objects::ShipControls, ParticleBuilder};
use cgmath::Point2;
use galactica_content::Content;
use galactica_gameobject::{GameData, GameShipHandle};

/// External resources we need to compute time steps
#[derive(Debug)]
pub struct StepResources<'a> {
	/// Game content
	pub ct: &'a Content,

	/// Game data
	pub dt: &'a mut GameData,

	/// Length of time step
	pub t: f32,

	/// Particles to create
	pub particles: &'a mut Vec<ParticleBuilder>,

	/// Player inputs
	pub player_controls: ShipControls,

	/// The ship that the player controls
	pub player: GameShipHandle,
}

/// Return values after computing time steps
#[derive(Debug)]
pub struct StepOutput {
	/// The player's position in world coordinates
	pub player_position: Point2<f32>,
}
